@@ -478,11 +478,7 @@ class ImageLabelDataset(ImageDataset):
             if os.path.exists(label_file):  
                 label_files.append(f"{base_name}.png")
             
-        self.logger.info("Calculating image sizes...")
-        self.image_sizes(self.img_dir, self.image_files, self.logger)
         
-        self.logger.info("Calculating label sizes...")
-        self.image_sizes(self.label_dir, label_files, self.logger)
 
         self.dataset_similarity(similarity_index, self.logger)
 
